@@ -106,7 +106,7 @@ class QDNSServer():
 
 	def kill_server(self,process=False):
 		try:
-			
+			self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
@@ -114,8 +114,10 @@ class QDNSServer():
 					process.kill()
 			if self.process != None:
 				self.process.kill()
+			return True
 		except:
 			pass
+		return False
 
 	def test_server(self,ip=None,port=None,domain=None):
 		try:
