@@ -132,7 +132,7 @@ class QHTTPProxyServer():
 
 	def kill_server(self,process=False):
 		try:
-			
+			self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
@@ -140,8 +140,10 @@ class QHTTPProxyServer():
 					process.kill()
 			if self.process != None:
 				self.process.kill()
+			return True
 		except:
 			pass
+		return False
 
 	def test_server(self,ip=None,port=None,domain=None):
 		try:
