@@ -128,7 +128,7 @@ class QPOP3Server():
 
 	def kill_server(self,process=False):
 		try:
-			
+			self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
@@ -136,9 +136,10 @@ class QPOP3Server():
 					process.kill()
 			if self.process != None:
 				self.process.kill()
+			return True
 		except:
 			pass
-
+		return False
 
 	def test_server(self,ip=None,port=None,username=None,password=None):
 		try:
