@@ -124,6 +124,7 @@ class QSMTPServer():
 
 	def kill_server(self,process=False):
 		try:
+			self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
@@ -131,8 +132,10 @@ class QSMTPServer():
 					process.kill()
 			if self.process != None:
 				self.process.kill()
+			return True
 		except:
 			pass
+		return False
 
 	def test_server(self,ip=None,port=None,username=None,password=None):
 		try:
